@@ -5,9 +5,9 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,14 +16,18 @@
  */
 package org.apache.log4j.chainsaw;
 
-import java.awt.BorderLayout;
-import java.awt.Component;
-import java.awt.Container;
-import java.awt.Dimension;
-import java.awt.EventQueue;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
-import java.awt.Insets;
+import org.apache.log4j.LogManager;
+import org.apache.log4j.Logger;
+import org.apache.log4j.chainsaw.helper.SwingHelper;
+import org.apache.log4j.chainsaw.prefs.SettingsManager;
+import org.apache.log4j.net.UDPReceiver;
+import org.apache.log4j.plugins.Receiver;
+
+import javax.swing.*;
+import javax.swing.text.SimpleAttributeSet;
+import javax.swing.text.StyleConstants;
+import javax.swing.text.StyledDocument;
+import java.awt.*;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.FocusEvent;
@@ -33,31 +37,7 @@ import java.net.MalformedURLException;
 import java.net.URISyntaxException;
 import java.net.URL;
 import java.util.List;
-
 import java.util.Locale;
-import javax.swing.AbstractAction;
-import javax.swing.BorderFactory;
-import javax.swing.ButtonGroup;
-import javax.swing.DefaultComboBoxModel;
-import javax.swing.JButton;
-import javax.swing.JCheckBox;
-import javax.swing.JComboBox;
-import javax.swing.JFrame;
-import javax.swing.JLabel;
-import javax.swing.JPanel;
-import javax.swing.JRadioButton;
-import javax.swing.JTextField;
-import javax.swing.JTextPane;
-import javax.swing.text.SimpleAttributeSet;
-import javax.swing.text.StyleConstants;
-import javax.swing.text.StyledDocument;
-
-import org.apache.log4j.LogManager;
-import org.apache.log4j.Logger;
-import org.apache.log4j.chainsaw.helper.SwingHelper;
-import org.apache.log4j.chainsaw.prefs.SettingsManager;
-import org.apache.log4j.net.SocketReceiver;
-import org.apache.log4j.net.UDPReceiver;
 
 
 /**
@@ -71,10 +51,10 @@ class ReceiverConfigurationPanel extends JPanel {
     private final PanelModel panelModel = new PanelModel();
 
     //network receiver widgets
-    private JComboBox networkReceiverPortComboBox;
-    private JComboBox networkReceiverClassNameComboBox;
-    private DefaultComboBoxModel networkReceiverClassNameComboBoxModel;
-    private DefaultComboBoxModel networkReceiverPortComboBoxModel;
+    private JComboBox<String> networkReceiverPortComboBox;
+    private JComboBox<String> networkReceiverClassNameComboBox;
+    private DefaultComboBoxModel<String> networkReceiverClassNameComboBoxModel;
+    private DefaultComboBoxModel<String> networkReceiverPortComboBoxModel;
 
     //log4j config receiver widgets
     private JButton browseLog4jConfigButton;
@@ -82,18 +62,18 @@ class ReceiverConfigurationPanel extends JPanel {
 
     //logfile receiver widgets
     private JButton browseLogFileButton;
-    private JComboBox logFileFormatTypeComboBox;
+    private JComboBox<String> logFileFormatTypeComboBox;
 
-    private JComboBox logFileFormatComboBox;
-    private JComboBox logFileFormatTimestampFormatComboBox;
+    private JComboBox<String> logFileFormatComboBox;
+    private JComboBox<String> logFileFormatTimestampFormatComboBox;
     private JTextField logFileURLTextField;
-    private DefaultComboBoxModel logFileFormatComboBoxModel;
-    private DefaultComboBoxModel logFileFormatTimestampFormatComboBoxModel;
+    private DefaultComboBoxModel<String> logFileFormatComboBoxModel;
+    private DefaultComboBoxModel<String> logFileFormatTimestampFormatComboBoxModel;
 
     //use existing configuration widgets
     private JButton browseForAnExistingConfigurationButton;
-    private DefaultComboBoxModel existingConfigurationComboBoxModel;
-    private JComboBox existingConfigurationComboBox;
+    private DefaultComboBoxModel<String> existingConfigurationComboBoxModel;
+    private JComboBox<String> existingConfigurationComboBox;
 
     //don't warn again widgets
     private JCheckBox dontwarnIfNoReceiver;
@@ -123,7 +103,7 @@ class ReceiverConfigurationPanel extends JPanel {
     //used as frame for file open dialogs
     private Container dialog;
 
-  ReceiverConfigurationPanel() {
+    ReceiverConfigurationPanel() {
         setBorder(BorderFactory.createEmptyBorder(5, 15, 5, 15));
         setLayout(new GridBagLayout());
 
@@ -174,7 +154,7 @@ class ReceiverConfigurationPanel extends JPanel {
         c.fill = GridBagConstraints.HORIZONTAL;
         c.insets = new Insets(10, 10, 10, 0);
         add(lowerPanel, c);
-        
+
         c = new GridBagConstraints();
         c.gridx = 0;
         c.gridy = yPos++;
@@ -194,11 +174,7 @@ class ReceiverConfigurationPanel extends JPanel {
          * This listener activates/deactivates certain controls based on the current
          * state of the options
          */
-        ActionListener al = new ActionListener() {
-                public void actionPerformed(ActionEvent e) {
-                    updateEnabledState((Component)e.getSource());
-                }
-            };
+        ActionListener al = e -> updateEnabledState((Component) e.getSource());
 
         logFileReceiverRadioButton.addActionListener(al);
         log4jConfigReceiverRadioButton.addActionListener(al);
@@ -231,59 +207,51 @@ class ReceiverConfigurationPanel extends JPanel {
         okButton = new JButton(" OK ");
         cancelButton = new JButton(" Cancel ");
 
-        List okCancelButtons = SwingHelper.orderOKCancelButtons(okButton, cancelButton);
+        List<JButton> okCancelButtons = SwingHelper.orderOKCancelButtons(okButton, cancelButton);
 
         c = new GridBagConstraints();
         c.fill = GridBagConstraints.HORIZONTAL;
         c.gridx = 2;
         c.gridy = 0;
         c.insets = new Insets(0, 0, 0, 10);
-        panel.add((JButton)okCancelButtons.get(0), c);
+        panel.add(okCancelButtons.get(0), c);
 
         c = new GridBagConstraints();
         c.fill = GridBagConstraints.HORIZONTAL;
         c.gridx = 3;
         c.gridy = 0;
-        panel.add((JButton)okCancelButtons.get(1), c);
+        panel.add(okCancelButtons.get(1), c);
 
-        cancelButton.addActionListener(new ActionListener()
-        {
-            public void actionPerformed(ActionEvent e)
-            {
+        cancelButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
                 panelModel.setCancelled(true);
                 completionActionListener.actionPerformed(new ActionEvent(this, -1, "cancelled"));
             }
         });
 
-        okButton.addActionListener(new ActionListener()
-        {
-            public void actionPerformed(ActionEvent e)
-            {
+        okButton.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent e) {
                 panelModel.setCancelled(false);
                 if (logFileFormatComboBox.getSelectedItem() != null && !(logFileFormatComboBox.getSelectedItem().toString().trim().equals(""))) {
-                  panelModel.setLogFormat(logFileFormatComboBox.getSelectedItem().toString());
+                    panelModel.setLogFormat(logFileFormatComboBox.getSelectedItem().toString());
                 }
                 completionActionListener.actionPerformed(new ActionEvent(this, -1, "ok"));
             }
         });
 
-      saveButton.addActionListener(new ActionListener()
-      {
-          public void actionPerformed(ActionEvent e)
-          {
+        saveButton.addActionListener(e -> {
             try {
                 URL url = browseFile("Choose a path and file name to save", false);
                 if (url != null) {
-                  File file = new File(url.toURI());
-                  panelModel.setSaveConfigFile(file);
+                    File file = new File(url.toURI());
+                    panelModel.setSaveConfigFile(file);
                 }
             } catch (Exception ex) {
                 logger.error(
                     "Error browsing for log file", ex);
             }
-          }
-      });
-      return panel;
+        });
+        return panel;
     }
 
     private JPanel buildBottomDescriptionPanel() {
@@ -312,19 +280,18 @@ class ReceiverConfigurationPanel extends JPanel {
     }
 
     private JPanel buildNetworkReceiverPanel() {
-        networkReceiverPortComboBoxModel = new DefaultComboBoxModel();
+        networkReceiverPortComboBoxModel = new DefaultComboBoxModel<>();
         networkReceiverPortComboBoxModel.addElement("4445");
         networkReceiverPortComboBoxModel.addElement("4560");
 
-        networkReceiverPortComboBox = new JComboBox(networkReceiverPortComboBoxModel);
+        networkReceiverPortComboBox = new JComboBox<>(networkReceiverPortComboBoxModel);
         networkReceiverPortComboBox.setEditable(true);
         networkReceiverPortComboBox.setOpaque(false);
 
-        networkReceiverClassNameComboBoxModel = new DefaultComboBoxModel();
-        networkReceiverClassNameComboBoxModel.addElement(SocketReceiver.class.getName());
+        networkReceiverClassNameComboBoxModel = new DefaultComboBoxModel<>();
         networkReceiverClassNameComboBoxModel.addElement(UDPReceiver.class.getName());
 
-        networkReceiverClassNameComboBox = new JComboBox(networkReceiverClassNameComboBoxModel);
+        networkReceiverClassNameComboBox = new JComboBox<>(networkReceiverClassNameComboBoxModel);
 
         networkReceiverClassNameComboBox.setEditable(false);
         networkReceiverClassNameComboBox.setOpaque(false);
@@ -352,20 +319,20 @@ class ReceiverConfigurationPanel extends JPanel {
     private JPanel buildLog4jConfigReceiverPanel() {
         log4jConfigURLTextField = new JTextField();
         browseLog4jConfigButton = new JButton(new AbstractAction(" Open File... ") {
-                    public void actionPerformed(ActionEvent e) {
-                        try {
+            public void actionPerformed(ActionEvent e) {
+                try {
 
-                            URL url = browseConfig();
+                    URL url = browseConfig();
 
-                            if (url != null) {
-                                log4jConfigURLTextField.setText(url.toExternalForm());
-                            }
-                        } catch (Exception ex) {
-                            logger.error(
-                                "Error browsing for log4j config file", ex);
-                        }
+                    if (url != null) {
+                        log4jConfigURLTextField.setText(url.toExternalForm());
                     }
-                });
+                } catch (Exception ex) {
+                    logger.error(
+                        "Error browsing for log4j config file", ex);
+                }
+            }
+        });
 
         browseLog4jConfigButton.setToolTipText(
             "Shows a File Open dialog to allow you to find a log4j configuration file");
@@ -446,11 +413,11 @@ class ReceiverConfigurationPanel extends JPanel {
         c.insets = new Insets(0, 0, 5, 5);
         panel.add(new JLabel(" Log file format type "), c);
 
-        DefaultComboBoxModel comboBoxModel = new DefaultComboBoxModel();
+        DefaultComboBoxModel<String> comboBoxModel = new DefaultComboBoxModel<>();
         comboBoxModel.addElement("LogFilePatternReceiver LogFormat");
         comboBoxModel.addElement("PatternLayout format");
 
-        logFileFormatTypeComboBox = new JComboBox(comboBoxModel);
+        logFileFormatTypeComboBox = new JComboBox<>(comboBoxModel);
         logFileFormatTypeComboBox.setOpaque(false);
 
         c = new GridBagConstraints();
@@ -467,9 +434,9 @@ class ReceiverConfigurationPanel extends JPanel {
         c.insets = new Insets(0, 5, 5, 5);
         panel.add(new JLabel(" Log file format "), c);
 
-        logFileFormatComboBoxModel = new DefaultComboBoxModel();
+        logFileFormatComboBoxModel = new DefaultComboBoxModel<>();
         seedLogFileFormatComboBoxModel();
-        logFileFormatComboBox = new JComboBox(logFileFormatComboBoxModel);
+        logFileFormatComboBox = new JComboBox<>(logFileFormatComboBoxModel);
         logFileFormatComboBox.setEditable(true);
         logFileFormatComboBox.setOpaque(false);
         logFileFormatComboBox.setSelectedIndex(0);
@@ -489,9 +456,9 @@ class ReceiverConfigurationPanel extends JPanel {
         c.insets = new Insets(0, 5, 5, 5);
         panel.add(new JLabel(" Log file timestamp format "), c);
 
-        logFileFormatTimestampFormatComboBoxModel = new DefaultComboBoxModel();
+        logFileFormatTimestampFormatComboBoxModel = new DefaultComboBoxModel<>();
         seedLogFileFormatTimestampComboBoxModel();
-        logFileFormatTimestampFormatComboBox = new JComboBox(logFileFormatTimestampFormatComboBoxModel);
+        logFileFormatTimestampFormatComboBox = new JComboBox<>(logFileFormatTimestampFormatComboBoxModel);
         logFileFormatTimestampFormatComboBox.setEditable(true);
         logFileFormatTimestampFormatComboBox.setOpaque(false);
 
@@ -506,14 +473,13 @@ class ReceiverConfigurationPanel extends JPanel {
         c = new GridBagConstraints();
         c.gridx = 0;
         c.gridy = 5;
-        c.gridwidth=5;
+        c.gridwidth = 5;
         c.insets = new Insets(15, 5, 0, 5);
         panel.add(new JLabel("<html> See PatternLayout or LogFilePatternReceiver JavaDoc for details </html>"), c);
         return panel;
     }
 
-    private void seedLogFileFormatComboBoxModel()
-    {
+    private void seedLogFileFormatComboBoxModel() {
         logFileFormatComboBoxModel.addElement("MESSAGE");
         logFileFormatComboBoxModel.addElement("%p %t %c - %m%n");
         logFileFormatComboBoxModel.addElement("LEVEL THREAD LOGGER - MESSAGE");
@@ -521,8 +487,7 @@ class ReceiverConfigurationPanel extends JPanel {
         logFileFormatComboBoxModel.addElement("TIMESTAMP LEVEL [LOGGER] MESSAGE");
     }
 
-    private void seedLogFileFormatTimestampComboBoxModel()
-    {
+    private void seedLogFileFormatTimestampComboBoxModel() {
         logFileFormatTimestampFormatComboBoxModel.addElement("yyyy-MM-dd HH:mm:ss,SSS");
         logFileFormatTimestampFormatComboBoxModel.addElement("yyyyMMdd HH:mm:ss.SSS");
         logFileFormatTimestampFormatComboBoxModel.addElement("yyyy/MM/dd HH:mm:ss");
@@ -533,9 +498,9 @@ class ReceiverConfigurationPanel extends JPanel {
     }
 
     private JPanel buildUseExistingConfigurationPanel() {
-        existingConfigurationComboBoxModel = new DefaultComboBoxModel();
+        existingConfigurationComboBoxModel = new DefaultComboBoxModel<>();
 
-        existingConfigurationComboBox = new JComboBox(existingConfigurationComboBoxModel);
+        existingConfigurationComboBox = new JComboBox<>(existingConfigurationComboBoxModel);
         existingConfigurationComboBox.setOpaque(false);
         existingConfigurationComboBox.setToolTipText("Previously loaded configurations can be chosen here");
         existingConfigurationComboBox.setEditable(true);
@@ -555,22 +520,22 @@ class ReceiverConfigurationPanel extends JPanel {
             });
 
         browseForAnExistingConfigurationButton = new JButton(new AbstractAction(" Open File... ") {
-                    public void actionPerformed(ActionEvent e) {
-                        try {
+            public void actionPerformed(ActionEvent e) {
+                try {
 
-                            URL url = browseConfig();
+                    URL url = browseConfig();
 
-                            if (url != null) {
-                                existingConfigurationComboBoxModel.addElement(url.toExternalForm());
-                                existingConfigurationComboBox.getModel().setSelectedItem(
-                                    url);
-                            }
-                        } catch (Exception ex) {
-                            logger.error(
-                                "Error browsing for Configuration file", ex);
-                        }
+                    if (url != null) {
+                        existingConfigurationComboBoxModel.addElement(url.toExternalForm());
+                        existingConfigurationComboBox.getModel().setSelectedItem(
+                            url);
                     }
-                });
+                } catch (Exception ex) {
+                    logger.error(
+                        "Error browsing for Configuration file", ex);
+                }
+            }
+        });
 
         browseForAnExistingConfigurationButton.setToolTipText(
             "Shows a File Open dialog to allow you to find a configuration file");
@@ -602,6 +567,7 @@ class ReceiverConfigurationPanel extends JPanel {
 
     /**
      * Returns the current Model/state of the chosen options by the user.
+     *
      * @return model
      */
     PanelModel getModel() {
@@ -612,6 +578,7 @@ class ReceiverConfigurationPanel extends JPanel {
      * Clients of this panel can configure the ActionListener to be used
      * when the user presses the OK button, so they can read
      * back this Panel's model top determine what to do.
+     *
      * @param actionListener listener which will be notified that ok was selected
      */
     void setCompletionActionListener(ActionListener actionListener) {
@@ -652,13 +619,9 @@ class ReceiverConfigurationPanel extends JPanel {
             result = null;
         }
         if (selectedFile != null) {
-          result = selectedFile.toURI().toURL();
+            result = selectedFile.toURI().toURL();
         }
-        EventQueue.invokeLater(new Runnable() {
-          public void run() {
-            dialog.setVisible(true);
-          }
-        });
+        EventQueue.invokeLater(() -> dialog.setVisible(true));
         return result;
     }
 
@@ -678,13 +641,9 @@ class ReceiverConfigurationPanel extends JPanel {
             result = null;
         }
         if (selectedFile != null) {
-          result = selectedFile.toURI().toURL();
+            result = selectedFile.toURI().toURL();
         }
-        EventQueue.invokeLater(new Runnable() {
-          public void run() {
-            dialog.setVisible(true);
-          }
-        });
+        EventQueue.invokeLater(() -> dialog.setVisible(true));
         return result;
     }
 
@@ -692,7 +651,7 @@ class ReceiverConfigurationPanel extends JPanel {
 
         JFrame frame = new JFrame();
         frame.getContentPane().add(new ReceiverConfigurationPanel());
-        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
+        frame.setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
         frame.pack();
         frame.setVisible(true);
     }
@@ -705,24 +664,23 @@ class ReceiverConfigurationPanel extends JPanel {
         return dontwarnIfNoReceiver.isSelected();
     }
 
-  public void setDialog(Container dialog) {
-    this.dialog = dialog;
-  }
+    public void setDialog(Container dialog) {
+        this.dialog = dialog;
+    }
 
-  /**
+    /**
      * This class represents the model of the chosen options the user
      * has configured.
-     *
      */
     class PanelModel {
 
-    private File file;
-    //default to cancelled
-    private boolean cancelled = true;
-    private String lastLogFormat;
-    private File saveConfigFile;
+        private File file;
+        //default to cancelled
+        private boolean cancelled = true;
+        private String lastLogFormat;
+        private File saveConfigFile;
 
-    public PanelModel(){
+        public PanelModel() {
             file = new File(SettingsManager.getInstance().getSettingsDirectory(), "receiver-config.xml");
         }
 
@@ -736,8 +694,8 @@ class ReceiverConfigurationPanel extends JPanel {
             return Integer.parseInt(networkReceiverPortComboBoxModel.getSelectedItem().toString());
         }
 
-        Class getNetworkReceiverClass() throws ClassNotFoundException {
-            return Class.forName(networkReceiverClassNameComboBoxModel.getSelectedItem().toString());
+        Class<? extends Receiver> getNetworkReceiverClass() throws ClassNotFoundException {
+            return Class.forName(networkReceiverClassNameComboBoxModel.getSelectedItem().toString()).asSubclass(Receiver.class);
         }
 
         boolean isLoadConfig() {
@@ -755,12 +713,9 @@ class ReceiverConfigurationPanel extends JPanel {
 
         URL getConfigToLoad() {
 
-            try
-            {
+            try {
                 return new URL(existingConfigurationComboBoxModel.getSelectedItem().toString());
-            }
-            catch (MalformedURLException e)
-            {
+            } catch (MalformedURLException e) {
                 return null;
             }
         }
@@ -775,23 +730,20 @@ class ReceiverConfigurationPanel extends JPanel {
         }
 
         File getSaveConfigFile() {
-          return saveConfigFile;
+            return saveConfigFile;
         }
 
         void setSaveConfigFile(File file) {
-          this.saveConfigFile = file;
+            this.saveConfigFile = file;
         }
 
         URL getLogFileURL() {
-            try
-            {
+            try {
                 Object item = logFileURLTextField.getText();
                 if (item != null) {
                     return new URL(item.toString());
                 }
-            }
-            catch (MalformedURLException e)
-            {
+            } catch (MalformedURLException e) {
                 logger.error("Error retrieving log file URL", e);
             }
             return null;
@@ -799,7 +751,7 @@ class ReceiverConfigurationPanel extends JPanel {
 
         String getLogFormat() {
             if (cancelled) {
-              return lastLogFormat;
+                return lastLogFormat;
             }
             Object item = logFileFormatComboBox.getSelectedItem();
             if (item != null) {
@@ -822,32 +774,29 @@ class ReceiverConfigurationPanel extends JPanel {
             return null;
         }
 
-        public void setCancelled(boolean cancelled)
-        {
+        public void setCancelled(boolean cancelled) {
             this.cancelled = cancelled;
         }
 
         public void setLogFormat(String lastLogFormat) {
-          this.lastLogFormat = lastLogFormat;
-          logFileFormatComboBoxModel.removeElement(lastLogFormat);
-          logFileFormatComboBoxModel.insertElementAt(lastLogFormat, 0);
-          logFileFormatComboBox.setSelectedIndex(0);
+            this.lastLogFormat = lastLogFormat;
+            logFileFormatComboBoxModel.removeElement(lastLogFormat);
+            logFileFormatComboBoxModel.insertElementAt(lastLogFormat, 0);
+            logFileFormatComboBox.setSelectedIndex(0);
         }
 
         public boolean isCancelled() {
-          return cancelled;
+            return cancelled;
         }
 
-    public File getLog4jConfigFile() {
-      try {
-        URL newConfigurationURL = new URL(log4jConfigURLTextField.getText());
-        return new File(newConfigurationURL.toURI());
-      } catch (URISyntaxException e) {
-        e.printStackTrace();
-      } catch (MalformedURLException e) {
-        e.printStackTrace();
-      }
-      return null;
+        public File getLog4jConfigFile() {
+            try {
+                URL newConfigurationURL = new URL(log4jConfigURLTextField.getText());
+                return new File(newConfigurationURL.toURI());
+            } catch (URISyntaxException | MalformedURLException e) {
+                e.printStackTrace();
+            }
+            return null;
+        }
     }
-  }
 }
